# Python Packages from Voken

[![PyPi Version](http://img.shields.io/pypi/v/voken.svg)](https://pypi.python.org/pypi/voken/)
![Python Version](https://shields.io/badge/python-%5E3.8-blue)

Python Packages from Voken Project

## shell

Embed and provide a interactive console...

```python
from voken import shell

shell.embed('welcome')

# >>>
```
